==> eslint_3.17.1~dfsg.orig.tar.xz: eslint-3.17.1/tests/lib/rules/no-continue.js <==
/**
 * @fileoverview Tests for no-continue rule.
 * @author Borislav Zhivkov
 */

"use strict";

//------------------------------------------------------------------------------
// Requirements
//------------------------------------------------------------------------------

const rule = require("../../../lib/rules/no-continue"),
    RuleTester = require("../../../lib/testers/rule-tester");

//------------------------------------------------------------------------------
// Tests
//------------------------------------------------------------------------------

const ruleTester = new RuleTester();

ruleTester.run("no-continue", rule, {
    valid: [
        "var sum = 0, i; for(i = 0; i < 10; i++){ if(i > 5) { sum += i; } }",
        "var sum = 0, i = 0; while(i < 10) { if(i > 5) { sum += i; } i++; }"
    ],

    invalid: [
        {
            code: "var sum = 0, i; for(i = 0; i < 10; i++){ if(i <= 5) { continue; } sum += i; }",
            errors: [{ message: "Unexpected use of continue statement.",
                type: "ContinueStatement" }]
        },
        {
            code: "var sum = 0, i; myLabel: for(i = 0; i < 10; i++){ if(i <= 5) { continue myLabel; } sum += i; }",
            errors: [{ message: "Unexpected use of continue statement.",
                type: "ContinueStatement" }]
        },
        {
            code: "var sum = 0, i = 0; while(i < 10) { if(i <= 5) { i++; continue; } sum += i; i++; }",
            errors: [{ message: "Unexpected use of continue statement.",
                type: "ContinueStatement" }]
        },
        {
            code: "var sum = 0, i = 0; myLabel: while(i < 10) { if(i <= 5) { i++; continue myLabel; } sum += i; i++; }",
            errors: [{ message: "Unexpected use of continue statement.",
                type: "ContinueStatement" }]
        }
    ]
});

==> eslint_4.10.0~dfsg.orig.tar.xz: eslint-4.10.0/tests/lib/rules/no-continue.js <==
/**
 * @fileoverview Tests for no-continue rule.
 * @author Borislav Zhivkov
 */

"use strict";

//------------------------------------------------------------------------------
// Requirements
//------------------------------------------------------------------------------

const rule = require("../../../lib/rules/no-continue"),
    RuleTester = require("../../../lib/testers/rule-tester");

//------------------------------------------------------------------------------
// Tests
//------------------------------------------------------------------------------

const ruleTester = new RuleTester();

ruleTester.run("no-continue", rule, {
    valid: [
        "var sum = 0, i; for(i = 0; i < 10; i++){ if(i > 5) { sum += i; } }",
        "var sum = 0, i = 0; while(i < 10) { if(i > 5) { sum += i; } i++; }"
    ],

    invalid: [
        {
            code: "var sum = 0, i; for(i = 0; i < 10; i++){ if(i <= 5) { continue; } sum += i; }",
            errors: [{
                message: "Unexpected use of continue statement.",
                type: "ContinueStatement"
            }]
        },
        {
            code: "var sum = 0, i; myLabel: for(i = 0; i < 10; i++){ if(i <= 5) { continue myLabel; } sum += i; }",
            errors: [{
                message: "Unexpected use of continue statement.",
                type: "ContinueStatement"
            }]
        },
        {
            code: "var sum = 0, i = 0; while(i < 10) { if(i <= 5) { i++; continue; } sum += i; i++; }",
            errors: [{
                message: "Unexpected use of continue statement.",
                type: "ContinueStatement"
            }]
        },
        {
            code: "var sum = 0, i = 0; myLabel: while(i < 10) { if(i <= 5) { i++; continue myLabel; } sum += i; i++; }",
            errors: [{
                message: "Unexpected use of continue statement.",
                type: "ContinueStatement"
            }]
        }
    ]
});
